@@ -2,7 +2,7 @@
 package RPerl::DataStructure::Hash;
 use strict;
 use warnings;
-our $VERSION = 0.005_000;
+our $VERSION = 0.006_000;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::DataStructure);
@@ -32,7 +32,21 @@ use RPerl::DataType::Scalar;
 use RPerl::DataType::Unknown;
 use RPerl::DataStructure::Array;
 
-# DEV NOTE, CORRELATION #rp18: RPerl::DataStructure::Array & Hash can not 'use RPerl;' so *__MODE_ID() subroutines are hard-coded here
+# [[[ EXPORTS ]]]
+# DEV NOTE: avoid "Undefined subroutine &main::integer_to_string called"
+use Exporter 'import';
+our @EXPORT = ( @RPerl::DataType::Void::EXPORT, 
+                @RPerl::DataType::Boolean::EXPORT, 
+                @RPerl::DataType::UnsignedInteger::EXPORT, 
+                @RPerl::DataType::Integer::EXPORT, 
+                @RPerl::DataType::Number::EXPORT, 
+                @RPerl::DataType::Character::EXPORT, 
+                @RPerl::DataType::String::EXPORT, 
+                @RPerl::DataType::Scalar::EXPORT, 
+                @RPerl::DataType::Unknown::EXPORT, 
+                @RPerl::DataStructure::Array::EXPORT);
+
+# DEV NOTE, CORRELATION #rp018: RPerl::DataStructure::Array & Hash can not 'use RPerl;' so *__MODE_ID() subroutines are hard-coded here
 package main;
 use strict;
 use warnings;
