@@ -20,16 +20,23 @@ use RPerl::Config;  # for $RPerl::DEBUG
 # short form
 #use Inline CPP => config => classes => sub { join('::', split('__', shift)); };
 
-# DEV NOTE, CORRELATION #rp11: replace -std=c++0x w/ -std=c++11 for std::string::pop_back()
+# DEV NOTE, CORRELATION #rp011: replace -std=c++0x w/ -std=c++11 for std::string::pop_back()
 # DEV NOTE: move ccflags outside %ARGS, make individual modules compose ccflags with possible cppflags right before calling Inline
 #our $CCFLAGSEX = '-DNO_XSLOCKS -Wno-deprecated -std=c++0x -Wno-reserved-user-defined-literal -Wno-literal-suffix';
 #our $CCFLAGSEX = '-DNO_XSLOCKS -Wno-deprecated -std=c++11 -Wno-reserved-user-defined-literal -Wno-literal-suffix';
 # DEV NOTE: add -Wno-unused-variable to suppress warnings in GCC v4.9
-our $CCFLAGSEX = '-Wno-unused-variable -DNO_XSLOCKS -Wno-deprecated -std=c++11 -Wno-reserved-user-defined-literal -Wno-literal-suffix';
+my $is_msvc_compiler = ($Config::Config{cc} =~ /cl/);
+
+our $CCFLAGSEX = $is_msvc_compiler ? '-DNO_XSLOCKS'
+    : '-Wno-unused-variable -DNO_XSLOCKS -Wno-deprecated -std=c++11 -Wno-reserved-user-defined-literal -Wno-literal-suffix';
 
 our %ARGS = (
     typemaps => "$RPerl::INCLUDE_PATH/typemap.rperl",
-    optimize => '-O3 -fomit-frame-pointer -march=native -g',  # disable default '-O2 -g' (or similar) from Perl core & Makemaker
+     # disable default '-O2 -g' (or similar) from Perl core & Makemaker
+    ($is_msvc_compiler
+        ? ()
+        : (optimize => '-O3 -fomit-frame-pointer -march=native -g')
+    ),
 
 # NEED UPGRADE: strip C++ incompat CFLAGS
 #  ccflags => $Config{ccflags} . ' -DNO_XSLOCKS -Wno-deprecated -std=c++0x -Wno-reserved-user-defined-literal -Wno-literal-suffix',
@@ -41,7 +48,7 @@ our %ARGS = (
     filters           => 'Preprocess',
     auto_include => # DEV NOTE: include non-RPerl files using AUTO_INCLUDE so they are not parsed by the 'Preprocess' filter
     [
-        # DEV NOTE, CORRELATION #rp24: sync include files in both RPerl/Inline.pm and rperlstandalone.h
+        # DEV NOTE, CORRELATION #rp024: sync include files in both RPerl/Inline.pm and rperlstandalone.h
         '#include <memory>',  # smart pointers for memory management
         '#include <iostream>',
         '#include <string>',
