@@ -17,7 +17,7 @@ our $VERSION = 0.001_000;
 
 our void $right_justify_20 = sub {
     my string_arrayref $input_strings = [];
-    print 'Please input zero or more strings, separated by <ENTER>, ended by <CTRL-D>:' . "\n";
+    print 'Please input zero or more strings, separated by <ENTER>, ended by <CTRL-D>:', "\n";
     while ( my string $input_string = <STDIN> ) {
         push @{$input_strings}, $input_string;
     }
@@ -29,7 +29,7 @@ our void $right_justify_20 = sub {
     foreach my string $input_string ( @{$input_strings} ) {
         chomp $input_string;
         print q{ } x ( 20 - ( length $input_string ) );
-        print $input_string . "\n";
+        print $input_string, "\n";
     }
 };
 
