@@ -3,7 +3,7 @@ package RPerl::Operation::Statement::VariableDeclaration;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.005_200;
+our $VERSION = 0.007_000;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::Operation::Statement);
@@ -18,7 +18,7 @@ use Scalar::Util 'blessed';
 # [[[ OO PROPERTIES ]]]
 our hashref $properties = {};
 
-# [[[ OO METHODS & SUBROUTINES ]]]
+# [[[ SUBROUTINES & OO METHODS ]]]
 
 our string_hashref::method $ast_to_rperl__generate = sub {
     ( my object $self, my string_hashref $modes) = @_;
@@ -185,7 +185,7 @@ our string_hashref::method $ast_to_cpp__generate__CPPOPS_CPPTYPES = sub {
     my string_hashref $cpp_source_subgroup;
     my string $self_class = ref $self;
 
- #    RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), received $self = ' . "\n" . RPerl::Parser::rperl_ast__dump($self) . "\n" );
+#    RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), received $self = ' . "\n" . RPerl::Parser::rperl_ast__dump($self) . "\n" );
 
     # unwrap VariableDeclaration_182, VariableDeclaration_183, VariableDeclaration_184, and VariableDeclaration_185 from Statement_156
     if ( $self_class eq 'Statement_156' ) {    # Statement -> VariableDeclaration
@@ -341,7 +341,9 @@ our string_hashref::method $ast_to_cpp__generate__CPPOPS_CPPTYPES = sub {
             }
             elsif ($is_constructor_call_special) {
                 if ( exists $rperlnamespaces_generated::RPERL->{ $type . '::' } ) {
-                    if ($type eq 'integer_arrayref_arrayref') {
+                    if (($type eq 'integer_arrayref_arrayref') or ($type eq 'number_arrayref_arrayref') or ($type eq 'string_arrayref_arrayref')) {
+                        my string $base_type = (split /_/, $type)[0];
+#                        RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have $base_type = ' . $base_type . "\n" );
                         $cpp_source_group->{CPP} .= '(';
                         if (not exists $opnamed_or_subexp_or_input_scolon->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[2]->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]) {
                             die 'ERROR ECOGEASCP60, CODE GENERATOR, ABSTRACT SYNTAX TO C++: first argument missing, constructor for type ' . $type . ', dying' . "\n";
@@ -351,7 +353,7 @@ our string_hashref::method $ast_to_cpp__generate__CPPOPS_CPPTYPES = sub {
                         }
                         my string $row_count_argument = $opnamed_or_subexp_or_input_scolon->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[2]->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0];
                         substr $row_count_argument, 0, 1, q{};  # remove leading '$' sigil
-                        $cpp_source_group->{CPP} .= $row_count_argument . ', integer_arrayref(';
+                        $cpp_source_group->{CPP} .= $row_count_argument . ', ' . $base_type . '_arrayref(';
 #                        RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have $opnamed_or_subexp_or_input_scolon->... = ' . "\n" . RPerl::Parser::rperl_ast__dump($opnamed_or_subexp_or_input_scolon->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[2]->{children}->[0]->{children}->[1]->{children}->[1]->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]) . "\n" );
                         my string $column_count_argument = $opnamed_or_subexp_or_input_scolon->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[2]->{children}->[0]->{children}->[1]->{children}->[1]->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0];
                         substr $column_count_argument, 0, 1, q{};  # remove leading '$' sigil
@@ -366,9 +368,52 @@ our string_hashref::method $ast_to_cpp__generate__CPPOPS_CPPTYPES = sub {
                 }
             }
             else {
-                $cpp_source_group->{CPP} .= q{ } . $assign . q{ };
-                $cpp_source_subgroup = $opnamed_or_subexp_or_input_scolon->{children}->[0]->ast_to_cpp__generate__CPPOPS_CPPTYPES($modes);       # subexpression
-                RPerl::Generator::source_group_append( $cpp_source_group, $cpp_source_subgroup );
+
+                my $subexpression = $opnamed_or_subexp_or_input_scolon->{children}->[0];
+#                RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have $subexpression = ' . "\n" . RPerl::Parser::rperl_ast__dump($subexpression) . "\n" );
+#                RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have (ref $subexpression) = ' . (ref $subexpression) . "\n" );
+#                RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have (ref $subexpression->{children}->[0]) = ' . (ref $subexpression->{children}->[0]) . "\n" );
+#                RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have (ref $subexpression->{children}->[0]->{children}->[0]) = ' . (ref $subexpression->{children}->[0]->{children}->[0]) . "\n" );
+#                RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have (ref $subexpression->{children}->[0]->{children}->[0]->{children}->[1]) = ' . (ref $subexpression->{children}->[0]->{children}->[0]->{children}->[1]) . "\n" );
+#                RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have $subexpression->{children}->[0]->{children}->[0]->{children}->[1]->{children} = ' . "\n" . $subexpression->{children}->[0]->{children}->[0]->{children}->[1]->{children} . "\n" );
+#                RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have $subexpression->{children}->[0]->{children}->[0]->{children}->[1]->{children} = ' . "\n" . Dumper($subexpression->{children}->[0]->{children}->[0]->{children}->[1]->{children}) . "\n" );
+#                RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have scalar @{$subexpression->{children}->[0]->{children}->[0]->{children}->[1]->{children}} = ' . "\n" . (scalar @{$subexpression->{children}->[0]->{children}->[0]->{children}->[1]->{children}}) . "\n" );
+
+                # test for empty array ref as value for variable initialization, discard in C++
+                if (
+                    (blessed $subexpression) and
+                    ((ref    $subexpression) eq 'SubExpressionOrInput_145') and
+                    (exists  $subexpression->{children}) and
+                    (defined $subexpression->{children}) and
+                    (defined $subexpression->{children}->[0]) and
+                    (blessed $subexpression->{children}->[0]) and
+                    ((ref    $subexpression->{children}->[0]) eq 'SubExpression_140') and
+                    (exists  $subexpression->{children}->[0]->{children}) and
+                    (defined $subexpression->{children}->[0]->{children}) and
+                    (defined $subexpression->{children}->[0]->{children}->[0]) and
+                    (blessed $subexpression->{children}->[0]->{children}->[0]) and
+                    ((ref    $subexpression->{children}->[0]->{children}->[0]) eq 'ArrayReference_198') and
+                    (exists  $subexpression->{children}->[0]->{children}->[0]->{children}) and
+                    (defined $subexpression->{children}->[0]->{children}->[0]->{children}) and
+                    (defined $subexpression->{children}->[0]->{children}->[0]->{children}->[0]) and
+                    (        $subexpression->{children}->[0]->{children}->[0]->{children}->[0] eq '[') and
+                    (defined $subexpression->{children}->[0]->{children}->[0]->{children}->[1]) and
+                    (blessed $subexpression->{children}->[0]->{children}->[0]->{children}->[1]) and
+                    ((ref    $subexpression->{children}->[0]->{children}->[0]->{children}->[1]) eq '_OPTIONAL') and
+                    (exists  $subexpression->{children}->[0]->{children}->[0]->{children}->[1]->{children}) and
+                    (defined $subexpression->{children}->[0]->{children}->[0]->{children}->[1]->{children}) and
+                    ((scalar @{$subexpression->{children}->[0]->{children}->[0]->{children}->[1]->{children}}) == 0) and
+                    (defined $subexpression->{children}->[0]->{children}->[0]->{children}->[2]) and
+                    (        $subexpression->{children}->[0]->{children}->[0]->{children}->[2] eq ']')
+                    ) {
+#                    RPerl::diag( 'in VariableDeclaration->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have empty array ref' . "\n");
+                    1;  # do nothing
+                }
+                else {
+                    $cpp_source_group->{CPP} .= q{ } . $assign . q{ };
+                    $cpp_source_subgroup = $opnamed_or_subexp_or_input_scolon->{children}->[0]->ast_to_cpp__generate__CPPOPS_CPPTYPES($modes);       # subexpression
+                    RPerl::Generator::source_group_append( $cpp_source_group, $cpp_source_subgroup );
+                }
             }
             $cpp_source_group->{CPP} .= $opnamed_or_subexp_or_input_scolon->{children}->[1];                                                     # semicolon
         }
