@@ -10,7 +10,7 @@ use RPerl::Test::Foo;
 use RPerl::Test::Bar;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub {
+our integer $empty_sub = sub {
     return 2;
 };
 
